summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2018-03-02 15:07:42 -0800
committerTim Smith <tsmith@chef.io>2018-03-02 15:07:42 -0800
commit709fc722eddca95f0b4c6b5eef6cd6bb37d794a7 (patch)
tree42bd50aa71c4447ff219163b6bc568d6215af1fe
parent43074e78329d3901f04080e4b3a1b04a39ba6bca (diff)
downloadchef-709fc722eddca95f0b4c6b5eef6cd6bb37d794a7.tar.gz
Rename provider -> subresource
Just did this to the cookbook as well Signed-off-by: Tim Smith <tsmith@chef.io>
-rw-r--r--lib/chef/resource/windows_feature.rb16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/chef/resource/windows_feature.rb b/lib/chef/resource/windows_feature.rb
index f79434ddc2..aadf0efb03 100644
--- a/lib/chef/resource/windows_feature.rb
+++ b/lib/chef/resource/windows_feature.rb
@@ -29,20 +29,20 @@ class Chef
property :timeout, Integer, default: 600
action :install do
- run_default_provider :install
+ run_default_subresource :install
end
action :remove do
- run_default_provider :remove
+ run_default_subresource :remove
end
action :delete do
- run_default_provider :delete
+ run_default_subresource :delete
end
action_class do
- # @return [Symbol] :windows_feature_dism or the provider specified in install_method property
- def locate_default_provider
+ # @return [Symbol] :windows_feature_dism or the subresource specified in install_method property
+ def locate_default_subresource
if new_resource.install_method
new_resource.install_method
else
@@ -50,10 +50,10 @@ class Chef
end
end
# call the appropriate windows_feature resource based on the specified provider
# @return [void]
- def run_default_provider(desired_action)
- case locate_default_provider
+ def run_default_subresource(desired_action)
+ case locate_default_subresource
when :windows_feature_dism
windows_feature_dism new_resource.name do
action desired_action
@@ -50,10 +50,10 @@ class Chef
end
end
- # call the appropriate windows_feature resource based on the specified provider
+ # call the appropriate windows_feature resource based on the specified subresource
# @return [void]